#
# spec file for package gdu
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gdu
Version:        5.30.1
Release:        1.3
Summary:        Fast disk usage analyzer with console interface
License:        MIT
URL:            https://github.com/dundee/gdu
Source:         https://github.com/dundee/gdu/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zstd
BuildRequires:  gzip
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.21

%description
Fast disk usage analyzer with console interface. Gdu is intended
primarily for SSD disks where it can fully utilize parallel
processing. HDDs work as well, but the performance gain is not so
huge.

%prep
%autosetup -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
# construct a BUILD_DATE compatible with reproducible builds
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
# populate LDFLAGS -X metadata for bespoke gdu version output
# Not best practice for Go apps but gdu assumes this data is present
LDFLAGS="-X github.com/dundee/gdu/v5/build.Version=%{version} -X 'github.com/dundee/gdu/v5/build.Time=${BUILD_DATE}' -X github.com/dundee/gdu/v5/build.User=OBS"
go build -ldflags "$LDFLAGS" ./cmd/%{name}

# compress upstream provided man page
gzip %{name}.1

%check
# execute the binary as a basic check
./%{name} --help

%install
install -D -m0755 -s %{name} %{buildroot}%{_bindir}/%{name}
install -D -m0644 %{name}.1.gz %{buildroot}%{_mandir}/man1/%{name}.1.gz

%files
%license LICENSE.md
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.gz

%changelog
* Tue Jan 14 2025 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Use a BUILD_DATE suitable to preserve reproducible builds
  * BUILD_DATE is used in bespoke LDFLAGS arg to go build expected
    by gdu --version output
* Tue Jan 14 2025 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Update to BuildRequires: golang(API) >= 1.21 matching go.mod
  * Move ldflags metadata out of ppc64 buildmode PIE conditional
* Tue Dec 31 2024 RN <R_Nik_C@proton.me>
- Version 5.30.1
  * fix: set default colors when config file does not exist
- Version 5.30.0
  * feat: show top largest files using `-t` or `--top` option in
    (gh#dundee/gdu#391)
  * feat: introduce more style options in (gh#dundee/gdu#396)
* Tue Dec 24 2024 Timo Schwaak <opensuse@tschwaak.de>
- gdu version output is incomplete when built with normal go build.
  Add ldflags to populate metadata needed by bespoke version
  reporting implementation. Changelog comments by Jeff Kowalczyk:
  * gdu --version ouput with package version 5.29.0:
    Version: development
    Built time:
    Built user:
  * Upstream code has a package build/build.go with an
    implementation managng the above output.
  * Generally we want to remove uses of ldflags for bespoke build
    metadata where possible. In this case, give gdu what it
    expects for now.
  * go1.24+ will have better main module version information in
    output of go version -m binaryname. Perhaps that facility and
    contacting gdu upstream about the issue will allow us to remove
    the ldflags usage from our packaging in the future.
* Fri Dec 20 2024 Timo Schwaak <opensuse@tschwaak.de>
- Version 5.29.0
  * feat: support for reading gzip, bzip2 and xz files by @dundee in #363
  * feat: add --show-mtime (-M) option by @dundee in #350
  * feat: add option --no-unicode to disable unicode symbols by @dundee in #362
  * fix: division by zero error in formatFileRow by @xroberx in #359
* Wed Apr 24 2024 Dominik Heidler <dheidler@suse.de>
- Version 5.28.0
  * feat: delete/empty items in background by @dundee in #336
  * feat: add --show-item-count (-C) option by @ramgp in #332
  * feat: add --no-delete option by @ramgp in #333
  * feat: ignore item by pressing I by @dundee in #345
  * feat: delete directory items in parallel by @dundee in #340
  * feat: add --sequential option for sequential scanning by @dundee in #322
* Wed Apr 10 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Drop autosetup -p 1 arg only needed when package has patches
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Call go build with relative path to subdirectory containing
    func main()
  * Add basic %%check to execute binary --help
* Thu Apr  4 2024 Dominik Heidler <dheidler@suse.de>
- Initial package version 5.27.0
